# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.archiver_create_cluster_log_archive_request import ArchiverCreateClusterLogArchiveRequest

class TestArchiverCreateClusterLogArchiveRequest(unittest.TestCase):
    """ArchiverCreateClusterLogArchiveRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArchiverCreateClusterLogArchiveRequest:
        """Test ArchiverCreateClusterLogArchiveRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArchiverCreateClusterLogArchiveRequest`
        """
        model = ArchiverCreateClusterLogArchiveRequest()
        if include_optional:
            return ArchiverCreateClusterLogArchiveRequest(
                uuid = '',
                timespan_minutes = 56,
                include_endpoints = True,
                redact_sensitive_data = True,
                send_to_cloudera = True,
                case_number = '',
                include_applications = True
            )
        else:
            return ArchiverCreateClusterLogArchiveRequest(
        )
        """

    def testArchiverCreateClusterLogArchiveRequest(self):
        """Test ArchiverCreateClusterLogArchiveRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_revision_meta import ServingRevisionMeta

class TestServingRevisionMeta(unittest.TestCase):
    """ServingRevisionMeta unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingRevisionMeta:
        """Test ServingRevisionMeta
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingRevisionMeta`
        """
        model = ServingRevisionMeta()
        if include_optional:
            return ServingRevisionMeta(
                name = '',
                traffic = 56,
                desired_replicas = 56,
                actual_replicas = 56,
                ready = True,
                failed = True,
                generation = '',
                conditions = [
                    cloudera.ai.inference.models.serving/condition.serving.Condition(
                        type = '', 
                        status = '', 
                        severity = '', 
                        last_transition_time = '', 
                        reason = '', 
                        message = '', )
                    ],
                replica_names = [
                    ''
                    ]
            )
        else:
            return ServingRevisionMeta(
        )
        """

    def testServingRevisionMeta(self):
        """Test ServingRevisionMeta"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_vllm_engine_args import ServingVLLMEngineArgs

class TestServingVLLMEngineArgs(unittest.TestCase):
    """ServingVLLMEngineArgs unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingVLLMEngineArgs:
        """Test ServingVLLMEngineArgs
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingVLLMEngineArgs`
        """
        model = ServingVLLMEngineArgs()
        if include_optional:
            return ServingVLLMEngineArgs(
                dtype = '',
                enable_prefix_caching = True,
                gpu_memory_utilization = 1.337,
                load_format = '',
                max_model_length = 56,
                max_num_batched_tokens = 56,
                max_num_seqs = 56,
                quantization = '',
                enforce_eager = True,
                trust_remote_code = True,
                kv_cache_dtype = '',
                block_size = 56,
                cpu_offload_gb = 56
            )
        else:
            return ServingVLLMEngineArgs(
        )
        """

    def testServingVLLMEngineArgs(self):
        """Test ServingVLLMEngineArgs"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_model_source import ServingModelSource

class TestServingModelSource(unittest.TestCase):
    """ServingModelSource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingModelSource:
        """Test ServingModelSource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingModelSource`
        """
        model = ServingModelSource()
        if include_optional:
            return ServingModelSource(
                registry_source = cloudera.ai.inference.models.serving/registry_source.serving.RegistrySource(
                    model_id = '', 
                    version = 56, 
                    registry_id = '', ),
                third_party_source = cloudera.ai.inference.models.serving/third_party_source.serving.ThirdPartySource(
                    url = '', 
                    model = '', 
                    provider_type = 'THIRD_PARTY_PROVIDER_UNSPECIFIED', 
                    api_key = '', 
                    aws_credentials = null, 
                    gcp_credentials = null, 
                    api_version = '', 
                    path_prefix = '', )
            )
        else:
            return ServingModelSource(
        )
        """

    def testServingModelSource(self):
        """Test ServingModelSource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_application_source import ServingApplicationSource

class TestServingApplicationSource(unittest.TestCase):
    """ServingApplicationSource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingApplicationSource:
        """Test ServingApplicationSource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingApplicationSource`
        """
        model = ServingApplicationSource()
        if include_optional:
            return ServingApplicationSource(
                container_source = cloudera.ai.inference.models.serving/application_container_source.serving.ApplicationContainerSource(
                    url = '', 
                    environment_variables = [
                        cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                            name = '', 
                            value = '', )
                        ], 
                    username = '', 
                    access_token = '', ),
                directory_source = cloudera.ai.inference.models.serving/application_directory_source.serving.ApplicationDirectorySource(
                    url = '', 
                    entry_point = '', 
                    runtime_image = '', 
                    environment_variables = [
                        cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                            name = '', 
                            value = '', )
                        ], 
                    credentials = cloudera.ai.inference.models.serving/application_directory_source_credentials.serving.ApplicationDirectorySourceCredentials(
                        github_credentials = cloudera.ai.inference.models.serving/github_source_credentials.serving.GithubSourceCredentials(
                            username = '', 
                            ssh_key = '', 
                            access_token = '', ), 
                        s3_credentials = cloudera.ai.inference.models.serving/s3_source_credentials.serving.S3SourceCredentials(
                            access_key_id = '', 
                            secret_access_key = '', ), ), )
            )
        else:
            return ServingApplicationSource(
        )
        """

    def testServingApplicationSource(self):
        """Test ServingApplicationSource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_get_quota_usage_response import ServingGetQuotaUsageResponse

class TestServingGetQuotaUsageResponse(unittest.TestCase):
    """ServingGetQuotaUsageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingGetQuotaUsageResponse:
        """Test ServingGetQuotaUsageResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingGetQuotaUsageResponse`
        """
        model = ServingGetQuotaUsageResponse()
        if include_optional:
            return ServingGetQuotaUsageResponse(
                usage = [
                    cloudera.ai.inference.models.serving/quota_usage.serving.QuotaUsage(
                        scope = '', 
                        identifier = '', 
                        metric = '', 
                        used = '', 
                        limit = '', 
                        remaining = '', 
                        unit = 'RATE_LIMIT_UNIT_UNKNOWN', 
                        resets_at = '', )
                    ]
            )
        else:
            return ServingGetQuotaUsageResponse(
        )
        """

    def testServingGetQuotaUsageResponse(self):
        """Test ServingGetQuotaUsageResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_deploy_endpoint_request import ServingDeployEndpointRequest

class TestServingDeployEndpointRequest(unittest.TestCase):
    """ServingDeployEndpointRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingDeployEndpointRequest:
        """Test ServingDeployEndpointRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingDeployEndpointRequest`
        """
        model = ServingDeployEndpointRequest()
        if include_optional:
            return ServingDeployEndpointRequest(
                namespace = '',
                name = '',
                source = cloudera.ai.inference.models.serving/model_source.serving.ModelSource(
                    registry_source = cloudera.ai.inference.models.serving/registry_source.serving.RegistrySource(
                        model_id = '', 
                        version = 56, 
                        registry_id = '', ), 
                    third_party_source = cloudera.ai.inference.models.serving/third_party_source.serving.ThirdPartySource(
                        url = '', 
                        model = '', 
                        provider_type = 'THIRD_PARTY_PROVIDER_UNSPECIFIED', 
                        api_key = '', 
                        aws_credentials = null, 
                        gcp_credentials = null, 
                        api_version = '', 
                        path_prefix = '', ), ),
                resources = cloudera.ai.inference.models.serving/resources.serving.Resources(
                    req_cpu = '', 
                    req_memory = '', 
                    num_gpus = '', 
                    gpu_resource_name = '', ),
                autoscaling = cloudera.ai.inference.models.serving/autoscaling.serving.Autoscaling(
                    min_replicas = '', 
                    max_replicas = '', 
                    autoscaling_config = null, ),
                labels = [
                    cloudera.ai.inference.models.serving/label.serving.Label(
                        key = '', 
                        value = '', )
                    ],
                description = '',
                traffic = '',
                vllm_engine_args = cloudera.ai.inference.models.serving/vllm_engine_args.serving.VLLMEngineArgs(
                    dtype = '', 
                    enable_prefix_caching = True, 
                    gpu_memory_utilization = 1.337, 
                    load_format = '', 
                    max_model_length = 56, 
                    max_num_batched_tokens = 56, 
                    max_num_seqs = 56, 
                    quantization = '', 
                    enforce_eager = True, 
                    trust_remote_code = True, 
                    kv_cache_dtype = '', 
                    block_size = 56, 
                    cpu_offload_gb = 56, ),
                instance_type = '',
                gpu_type = '',
                inference_logging_config = cloudera.ai.inference.models.serving/inference_logging_config.serving.InferenceLoggingConfig(
                    enabled = True, 
                    explainer_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                        bucket_url = '', 
                        access_key_id = '', 
                        secret_access_key = '', 
                        region = '', ), 
                    explainer_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                        bucket_url = '', 
                        client_id = '', 
                        client_secret = '', 
                        tenant_id = '', 
                        subscription_id = '', 
                        access_token = '', 
                        access_token_expiration_seconds = 56, 
                        service_url = '', ), 
                    explainer_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                        bucket_url = '', 
                        key_file = '', ), 
                    explainer_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                        datalake_crn = '', 
                        path = '', 
                        resolved_storage_url = '', ), 
                    predictor_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                        bucket_url = '', 
                        access_key_id = '', 
                        secret_access_key = '', 
                        region = '', ), 
                    predictor_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                        bucket_url = '', 
                        client_id = '', 
                        client_secret = '', 
                        tenant_id = '', 
                        subscription_id = '', 
                        access_token = '', 
                        access_token_expiration_seconds = 56, 
                        service_url = '', ), 
                    predictor_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                        bucket_url = '', 
                        key_file = '', ), 
                    predictor_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                        datalake_crn = '', 
                        path = '', 
                        resolved_storage_url = '', ), 
                    transformer_s3_config = , 
                    transformer_abs_config = , 
                    transformer_gcs_config = , 
                    transformer_datalake_config = , 
                    format = 'LOGGING_FORMAT_UNKNOWN', 
                    batch_size = 56, 
                    rollover_frequency = 'ROLLOVER_FREQUENCY_UNKNOWN', ),
                ml_user_permission = '',
                vllm_args = '',
                deployment_mode = 'DEPLOYMENT_MODE_UNKNOWN',
                environment_variables = [
                    cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                        name = '', 
                        value = '', )
                    ],
                task_override = 'TASK_UNKNOWN',
                rate_limit = cloudera.ai.inference.models.serving/rate_limit_config.serving.RateLimitConfig(
                    request_rate = null, 
                    token_budget = null, )
            )
        else:
            return ServingDeployEndpointRequest(
        )
        """

    def testServingDeployEndpointRequest(self):
        """Test ServingDeployEndpointRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_optimization_profile import ServingOptimizationProfile

class TestServingOptimizationProfile(unittest.TestCase):
    """ServingOptimizationProfile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingOptimizationProfile:
        """Test ServingOptimizationProfile
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingOptimizationProfile`
        """
        model = ServingOptimizationProfile()
        if include_optional:
            return ServingOptimizationProfile(
                gpu = '',
                gpu_device = '',
                gpu_count = '',
                precision = '',
                release = '',
                embed_config = cloudera.ai.inference.models.serving/embed_config.serving.EmbedConfig(
                    dimension = 56, 
                    max_tokens = 56, ),
                text_gen_config = cloudera.ai.inference.models.serving/text_generation_config.serving.TextGenerationConfig(
                    llm_engine = '', 
                    max_image_size = '', 
                    profile = '', ),
                rank_config = cloudera.ai.inference.models.serving/rank_config.serving.RankConfig(
                    max_tokens = 56, 
                    max_passages = 56, )
            )
        else:
            return ServingOptimizationProfile(
        )
        """

    def testServingOptimizationProfile(self):
        """Test ServingOptimizationProfile"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling

class TestServingAutoscaling(unittest.TestCase):
    """ServingAutoscaling unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingAutoscaling:
        """Test ServingAutoscaling
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingAutoscaling`
        """
        model = ServingAutoscaling()
        if include_optional:
            return ServingAutoscaling(
                min_replicas = '',
                max_replicas = '',
                autoscaling_config = cloudera.ai.inference.models.serving/autoscaling_config.serving.AutoscalingConfig(
                    metric = '', 
                    target = '', 
                    target_utilization = '', 
                    scale_to_zero_retention = '', 
                    activation_scale = '', 
                    scale_down_delay = '', 
                    panic_window_percentage = '', 
                    panic_threshold = '', 
                    stable_window = '', )
            )
        else:
            return ServingAutoscaling(
        )
        """

    def testServingAutoscaling(self):
        """Test ServingAutoscaling"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.archiver_delete_cluster_log_archive_request import ArchiverDeleteClusterLogArchiveRequest

class TestArchiverDeleteClusterLogArchiveRequest(unittest.TestCase):
    """ArchiverDeleteClusterLogArchiveRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArchiverDeleteClusterLogArchiveRequest:
        """Test ArchiverDeleteClusterLogArchiveRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArchiverDeleteClusterLogArchiveRequest`
        """
        model = ArchiverDeleteClusterLogArchiveRequest()
        if include_optional:
            return ArchiverDeleteClusterLogArchiveRequest(
                uuid = '',
                archive_id = ''
            )
        else:
            return ArchiverDeleteClusterLogArchiveRequest(
        )
        """

    def testArchiverDeleteClusterLogArchiveRequest(self):
        """Test ArchiverDeleteClusterLogArchiveRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_application_source import ServingApplicationSource
from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling
from cloudera.ai.inference.models.serving_label import ServingLabel
from cloudera.ai.inference.models.serving_resources import ServingResources
from typing import Optional, Set
from typing_extensions import Self

class ServingDeployApplicationRequest(BaseModel):
    """
    ServingDeployApplicationRequest
    """ # noqa: E501
    namespace: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    subdomain: Optional[StrictStr] = None
    source: Optional[ServingApplicationSource] = None
    resources: Optional[ServingResources] = None
    autoscaling: Optional[ServingAutoscaling] = None
    labels: Optional[List[ServingLabel]] = None
    description: Optional[StrictStr] = None
    traffic: Optional[StrictStr] = None
    instance_type: Optional[StrictStr] = None
    is_update: Optional[StrictBool] = None
    is_web_app: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["namespace", "name", "subdomain", "source", "resources", "autoscaling", "labels", "description", "traffic", "instance_type", "is_update", "is_web_app"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingDeployApplicationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict['source'] = self.source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of resources
        if self.resources:
            _dict['resources'] = self.resources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of autoscaling
        if self.autoscaling:
            _dict['autoscaling'] = self.autoscaling.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item_labels in self.labels:
                if _item_labels:
                    _items.append(_item_labels.to_dict())
            _dict['labels'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingDeployApplicationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "namespace": obj.get("namespace"),
            "name": obj.get("name"),
            "subdomain": obj.get("subdomain"),
            "source": ServingApplicationSource.from_dict(obj["source"]) if obj.get("source") is not None else None,
            "resources": ServingResources.from_dict(obj["resources"]) if obj.get("resources") is not None else None,
            "autoscaling": ServingAutoscaling.from_dict(obj["autoscaling"]) if obj.get("autoscaling") is not None else None,
            "labels": [ServingLabel.from_dict(_item) for _item in obj["labels"]] if obj.get("labels") is not None else None,
            "description": obj.get("description"),
            "traffic": obj.get("traffic"),
            "instance_type": obj.get("instance_type"),
            "is_update": obj.get("is_update"),
            "is_web_app": obj.get("is_web_app")
        })
        return _obj


